@@ -28,15 +28,18 @@
 #include <unistd.h>
 #include <string.h>
 #include <signal.h>
+#include <sys/signalfd.h>
 
 #include <gdbus.h>
 
 #include "near.h"
 
 static struct {
-	near_bool_t constant_poll;
+	bool constant_poll;
+	bool default_powered;
 } near_settings  = {
 	.constant_poll = FALSE,
+	.default_powered = FALSE,
 };
 
 static GKeyFile *load_config(const char *file)
@@ -65,18 +68,23 @@ static GKeyFile *load_config(const char *file)
 static void parse_config(GKeyFile *config)
 {
 	GError *error = NULL;
-	gboolean boolean;
+	bool boolean;
 
-	if (config == NULL)
+	if (!config)
 		return;
 
 	DBG("parsing main.conf");
 
 	boolean = g_key_file_get_boolean(config, "General",
 						"ConstantPoll", &error);
-	if (error == NULL)
+	if (!error)
 		near_settings.constant_poll = boolean;
 
+	boolean = g_key_file_get_boolean(config, "General",
+						"DefaultPowered", &error);
+	if (!error)
+		near_settings.default_powered = boolean;
+
 	g_clear_error(&error);
 }
 
@@ -84,16 +92,72 @@ static GMainLoop *main_loop = NULL;
 
 static volatile sig_atomic_t __terminated = 0;
 
-static void sig_term(int sig)
+static gboolean signal_handler(GIOChannel *channel, GIOCondition cond,
+							gpointer user_data)
 {
-	if (__terminated > 0)
-		return;
+	struct signalfd_siginfo si;
+	ssize_t result;
+	int fd;
 
-	__terminated = 1;
+	if (cond & (G_IO_NVAL | G_IO_ERR | G_IO_HUP))
+		return FALSE;
 
-	near_info("Terminating");
+	fd = g_io_channel_unix_get_fd(channel);
 
-	g_main_loop_quit(main_loop);
+	result = read(fd, &si, sizeof(si));
+	if (result != sizeof(si))
+		return FALSE;
+
+	switch (si.ssi_signo) {
+	case SIGINT:
+	case SIGTERM:
+		if (__terminated == 0) {
+			near_info("Terminating");
+			g_main_loop_quit(main_loop);
+		}
+
+		__terminated = 1;
+		break;
+	}
+
+	return TRUE;
+}
+
+static guint setup_signalfd(void)
+{
+	GIOChannel *channel;
+	guint source;
+	sigset_t mask;
+	int fd;
+
+	sigemptyset(&mask);
+	sigaddset(&mask, SIGINT);
+	sigaddset(&mask, SIGTERM);
+
+	if (sigprocmask(SIG_BLOCK, &mask, NULL) < 0) {
+		perror("Failed to set signal mask");
+		return 0;
+	}
+
+	fd = signalfd(-1, &mask, 0);
+	if (fd < 0) {
+		perror("Failed to create signal descriptor");
+		return 0;
+	}
+
+	channel = g_io_channel_unix_new(fd);
+
+	g_io_channel_set_close_on_unref(channel, TRUE);
+	g_io_channel_set_encoding(channel, NULL, NULL);
+	g_io_channel_set_buffered(channel, FALSE);
+
+	source = g_io_add_watch(channel,
+				G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_NVAL,
+				signal_handler, NULL);
+
+	g_io_channel_unref(channel);
+
+	return source;
 }
 
 static void disconnect_callback(DBusConnection *conn, void *user_data)
@@ -109,7 +173,7 @@ static gchar *option_noplugin = NULL;
 static gboolean option_detach = TRUE;
 static gboolean option_version = FALSE;
 
-static gboolean parse_debug(const char *key, const char *value,
+static bool parse_debug(const char *key, const char *value,
 					gpointer user_data, GError **error)
 {
 	if (value)
@@ -117,7 +181,7 @@ static gboolean parse_debug(const char *key, const char *value,
 	else
 		option_debug = g_strdup("*");
 
-	return TRUE;
+	return true;
 }
 
 static GOptionEntry options[] = {
@@ -136,12 +200,15 @@ static GOptionEntry options[] = {
 	{ NULL },
 };
 
-near_bool_t near_setting_get_bool(const char *key)
+bool near_setting_get_bool(const char *key)
 {
-	if (g_str_equal(key, "ConstantPoll") == TRUE)
+	if (g_str_equal(key, "ConstantPoll"))
 		return near_settings.constant_poll;
 
-	return FALSE;
+	if (g_str_equal(key, "DefaultPowered"))
+		return near_settings.default_powered;
+
+	return false;
 }
 
 int main(int argc, char *argv[])
@@ -151,13 +218,13 @@ int main(int argc, char *argv[])
 	DBusConnection *conn;
 	DBusError err;
 	GKeyFile *config;
-	struct sigaction sa;
+	guint signal;
 
 	context = g_option_context_new(NULL);
 	g_option_context_add_main_entries(context, options, NULL);
 
-	if (g_option_context_parse(context, &argc, &argv, &error) == FALSE) {
-		if (error != NULL) {
+	if (!g_option_context_parse(context, &argc, &argv, &error)) {
+		if (error) {
 			g_printerr("%s\n", error->message);
 			g_error_free(error);
 		} else
@@ -167,25 +234,20 @@ int main(int argc, char *argv[])
 
 	g_option_context_free(context);
 
-	if (option_version == TRUE) {
+	if (option_version) {
 		printf("%s\n", VERSION);
 		exit(0);
 	}
 
-	if (option_detach == TRUE) {
-		if (daemon(0, 0)) {
-			perror("Can't start daemon");
-			exit(1);
-		}
-	}
-
 	main_loop = g_main_loop_new(NULL, FALSE);
 
+	signal = setup_signalfd();
+
 	dbus_error_init(&err);
 
 	conn = g_dbus_setup_bus(DBUS_BUS_SYSTEM, NFC_SERVICE, &err);
-	if (conn == NULL) {
-		if (dbus_error_is_set(&err) == TRUE) {
+	if (!conn) {
+		if (dbus_error_is_set(&err)) {
 			fprintf(stderr, "%s\n", err.message);
 			dbus_error_free(&err);
 		} else
@@ -202,30 +264,40 @@ int main(int argc, char *argv[])
 
 	parse_config(config);
 
-	__near_netlink_init();
+	if (__near_netlink_init() < 0) {
+		near_error("*** NETLINK INITIALIZATION FAILED ***");
+		exit(1);
+	}
+
 	__near_tag_init();
 	__near_device_init();
 	__near_adapter_init();
 	__near_ndef_init();
+	__near_snep_core_init();
 	__near_manager_init(conn);
-	__near_bluetooth_init();
 	__near_agent_init();
+	__near_bluetooth_init();
 
 	__near_plugin_init(option_plugin, option_noplugin);
 
-	memset(&sa, 0, sizeof(sa));
-	sa.sa_handler = sig_term;
-	sigaction(SIGINT, &sa, NULL);
-	sigaction(SIGTERM, &sa, NULL);
+	if (option_detach) {
+		if (daemon(0, 0)) {
+			perror("Can't start daemon");
+			exit(1);
+		}
+	}
 
 	g_main_loop_run(main_loop);
 
+	g_source_remove(signal);
+
 	__near_plugin_cleanup();
 
 	__near_agent_cleanup();
 	__near_bluetooth_cleanup();
 	__near_manager_cleanup();
 	__near_ndef_cleanup();
+	__near_snep_core_cleanup();
 	__near_adapter_cleanup();
 	__near_device_cleanup();
 	__near_tag_cleanup();
